#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2019/10/21 21:11
Desc: 宏观经济配置文件
"""

# urls-china
JS_CHINA_CPI_YEARLY_URL = (
    "https://cdn.jin10.com/dc/reports/dc_chinese_cpi_yoy_all.js?v={}&_={}"
)
JS_CHINA_CPI_MONTHLY_URL = (
    "https://cdn.jin10.com/dc/reports/dc_chinese_cpi_mom_all.js?v={}&_={}"
)
JS_CHINA_M2_YEARLY_URL = (
    "https://cdn.jin10.com/dc/reports/dc_chinese_m2_money_supply_yoy_all.js?v={}&_={}"
)
JS_CHINA_PPI_YEARLY_URL = (
    "https://cdn.jin10.com/dc/reports/dc_chinese_ppi_yoy_all.js?v={}&_={}"
)
JS_CHINA_PMI_YEARLY_URL = (
    "https://cdn.jin10.com/dc/reports/dc_chinese_manufacturing_pmi_all.js?v={}&_={}"
)
JS_CHINA_GDP_YEARLY_URL = (
    "https://cdn.jin10.com/dc/reports/dc_chinese_gdp_yoy_all.js?v={}&_={}"
)
JS_CHINA_CX_PMI_YEARLY_URL = "https://cdn.jin10.com/dc/reports/dc_chinese_caixin_manufacturing_pmi_all.js?v={}&_={}"
JS_CHINA_CX_SERVICE_PMI_YEARLY_URL = (
    "https://cdn.jin10.com/dc/reports/dc_chinese_caixin_services_pmi_all.js?v={}&_={}"
)
JS_CHINA_FX_RESERVES_YEARLY_URL = (
    "https://cdn.jin10.com/dc/reports/dc_chinese_fx_reserves_all.js?v={}&_={}"
)
JS_CHINA_ENERGY_DAILY_URL = (
    "https://cdn.jin10.com/dc/reports/dc_qihuo_energy_report_all.js?v={}&_={}"
)
JS_CHINA_NON_MAN_PMI_MONTHLY_URL = (
    "https://cdn.jin10.com/dc/reports/dc_chinese_non_manufacturing_pmi_all.js?v={}&_={}"
)
JS_CHINA_RMB_DAILY_URL = "https://cdn.jin10.com/dc/reports/dc_rmb_data_all.js?v={}&_={}"
JS_CHINA_MARKET_MARGIN_SZ_URL = (
    "https://cdn.jin10.com/dc/reports/dc_market_margin_sz_all.js?v={}&_={}"
)
JS_CHINA_MARKET_MARGIN_SH_URL = (
    "https://cdn.jin10.com/dc/reports/dc_market_margin_sse_all.js?v={}&_={}"
)
JS_CHINA_REPORT_URL = "https://cdn.jin10.com/dc/reports/dc_sge_report_all.js?v={}&_={}"

# urls-usa
JS_USA_INTEREST_RATE_URL = (
    "https://cdn.jin10.com/dc/reports/dc_usa_interest_rate_decision_all.js?v={}&_={}"
)
JS_USA_NON_FARM_URL = (
    "https://cdn.jin10.com/dc/reports/dc_nonfarm_payrolls_all.js?v={}&_={}"
)
JS_USA_UNEMPLOYMENT_RATE_URL = (
    "https://cdn.jin10.com/dc/reports/dc_usa_unemployment_rate_all.js??v={}&_={}"
)
JS_USA_EIA_CRUDE_URL = (
    "https://cdn.jin10.com/dc/reports/dc_eia_crude_oil_all.js?v={}&_={}"
)
JS_USA_INITIAL_JOBLESS_URL = (
    "https://cdn.jin10.com/dc/reports/dc_initial_jobless_all.js?v={}&_={}"
)
JS_USA_CORE_PCE_PRICE_URL = (
    "https://cdn.jin10.com/dc/reports/dc_usa_core_pce_price_all.js?v={}&_={}"
)
JS_USA_CPI_MONTHLY_URL = "https://cdn.jin10.com/dc/reports/dc_usa_cpi_all.js?v={}&_={}"
JS_USA_LMCI_URL = "https://cdn.jin10.com/dc/reports/dc_usa_lmci_all.js?v={}&_={}"
JS_USA_ADP_NONFARM_URL = (
    "https://cdn.jin10.com/dc/reports/dc_adp_nonfarm_employment_all.js?v={}&_={}"
)
JS_USA_GDP_MONTHLY_URL = "https://cdn.jin10.com/dc/reports/dc_usa_gdp_all.js?v={}&_={}"
JS_USA_EIA_CRUDE_PRODUCE_URL = (
    "https://cdn.jin10.com/dc/reports/dc_eia_crude_oil_produce_all.js?v={}&_={}"
)

# urls-euro
JS_EURO_RATE_DECISION_URL = (
    "https://cdn.jin10.com/dc/reports/dc_interest_rate_decision_all.js?v={}&_={}"
)

# urls-constitute
JS_CONS_GOLD_ETF_URL = "https://cdn.jin10.com/dc/reports/dc_etf_gold_all.js?v={}&_={}"
JS_CONS_SLIVER_ETF_URL = (
    "https://cdn.jin10.com/dc/reports/dc_etf_sliver_all.js?v={}&_={}"
)
JS_CONS_OPEC_URL = "https://cdn.jin10.com/dc/reports/dc_opec_report_all.js??v={}&_={}"

usa_name_url_map = {
    "美联储决议报告": "//datacenter.jin10.com/reportType/dc_usa_interest_rate_decision",
    "美国非农就业人数报告": "//datacenter.jin10.com/reportType/dc_nonfarm_payrolls",
    "美国失业率报告": "//datacenter.jin10.com/reportType/dc_usa_unemployment_rate",
    "美国CPI月率报告": "//datacenter.jin10.com/reportType/dc_usa_cpi",
    "美国初请失业金人数报告": "//datacenter.jin10.com/reportType/dc_initial_jobless",
    "美国核心PCE物价指数年率报告": "//datacenter.jin10.com/reportType/dc_usa_core_pce_price",
    "美国EIA原油库存报告": "//datacenter.jin10.com/reportType/dc_eia_crude_oil",
    "美联储劳动力市场状况指数报告": "//datacenter.jin10.com/reportType/dc_usa_lmci",
    "美国ADP就业人数报告": "//datacenter.jin10.com/reportType/dc_adp_nonfarm_employment",
    "美国国内生产总值(GDP)报告": "//datacenter.jin10.com/reportType/dc_usa_gdp",
    "美国原油产量报告": "//datacenter.jin10.com/reportType/dc_eia_crude_oil_produce",
    "美国零售销售月率报告": "//datacenter.jin10.com/reportType/dc_usa_retail_sales",
    "美国商品期货交易委员会CFTC外汇类非商业持仓报告": "//datacenter.jin10.com/reportType/dc_cftc_nc_report",
    "美国NFIB小型企业信心指数报告": "//datacenter.jin10.com/reportType/dc_usa_nfib_small_business",
    "贝克休斯钻井报告": "//datacenter.jin10.com/reportType/dc_rig_count_summary",
    "美国谘商会消费者信心指数报告": "//datacenter.jin10.com/reportType/dc_usa_cb_consumer_confidence",
    "美国FHFA房价指数月率报告": "//datacenter.jin10.com/reportType/dc_usa_house_price_index",
    "美国个人支出月率报告": "//datacenter.jin10.com/reportType/dc_usa_personal_spending",
    "美国生产者物价指数(PPI)报告": "//datacenter.jin10.com/reportType/dc_usa_ppi",
    "美国成屋销售总数年化报告": "//datacenter.jin10.com/reportType/dc_usa_exist_home_sales",
    "美国成屋签约销售指数月率报告": "//datacenter.jin10.com/reportType/dc_usa_pending_home_sales",
    "美国S&P/CS20座大城市房价指数年率报告": "//datacenter.jin10.com/reportType/dc_usa_spcs20",
    "美国进口物价指数报告": "//datacenter.jin10.com/reportType/dc_usa_import_price",
    "美国营建许可总数报告": "//datacenter.jin10.com/reportType/dc_usa_building_permits",
    "美国商品期货交易委员会CFTC商品类非商业持仓报告": "//datacenter.jin10.com/reportType/dc_cftc_c_report",
    "美国挑战者企业裁员人数报告": "//datacenter.jin10.com/reportType/dc_usa_job_cuts",
    "美国实际个人消费支出季率初值报告": "//datacenter.jin10.com/reportType/dc_usa_real_consumer_spending",
    "美国贸易帐报告": "//datacenter.jin10.com/reportType/dc_usa_trade_balance",
    "美国经常帐报告": "//datacenter.jin10.com/reportType/dc_usa_current_account",
    "美国API原油库存报告": "//datacenter.jin10.com/reportType/dc_usa_api_crude_stock",
    "美国工业产出月率报告": "//datacenter.jin10.com/reportType/dc_usa_industrial_production",
    "美国耐用品订单月率报告": "//datacenter.jin10.com/reportType/dc_usa_durable_goods_orders",
    "美国工厂订单月率报告": "//datacenter.jin10.com/reportType/dc_usa_factory_orders",
    "Markit服务业PMI终值": "//datacenter.jin10.com/reportType/dc_usa_services_pmi",
    "商业库存月率": "//datacenter.jin10.com/reportType/dc_usa_business_inventories",
    "美国ISM非制造业PMI": "//datacenter.jin10.com/reportType/dc_usa_ism_non_pmi",
    "NAHB房产市场指数": "//datacenter.jin10.com/reportType/dc_usa_nahb_house_market_index",
    "新屋开工总数年化": "//datacenter.jin10.com/reportType/dc_usa_house_starts",
    "美国新屋销售总数年化": "//datacenter.jin10.com/reportType/dc_usa_new_home_sales",
    "美国Markit制造业PMI初值报告": "//datacenter.jin10.com/reportType/dc_usa_pmi",
    "美国ISM制造业PMI报告": "//datacenter.jin10.com/reportType/dc_usa_ism_pmi",
    "美国密歇根大学消费者信心指数初值报告": "//datacenter.jin10.com/reportType/dc_usa_michigan_consumer_sentiment",
    "美国出口价格指数报告": "//datacenter.jin10.com/reportType/dc_usa_export_price",
    "美国核心生产者物价指数(PPI)报告": "//datacenter.jin10.com/reportType/dc_usa_core_ppi",
    "美国核心CPI月率报告": "//datacenter.jin10.com/reportType/dc_usa_core_cpi",
    "美国EIA俄克拉荷马州库欣原油库存报告": "//datacenter.jin10.com/reportType/dc_eia_cushing_oil",
    "美国EIA精炼油库存报告": "//datacenter.jin10.com/reportType/dc_eia_distillates_stocks",
    "美国EIA天然气库存报告": "//datacenter.jin10.com/reportType/dc_eia_natural_gas",
    "美国EIA汽油库存报告": "//datacenter.jin10.com/reportType/dc_eia_gasoline",
}
china_name_url_map = {
    "郑州商品交易所期货每日行情": "//datacenter.jin10.com/reportType/dc_czce_futures_data",
    "中国CPI年率报告": "//datacenter.jin10.com/reportType/dc_chinese_cpi_yoy",
    "中国PPI年率报告": "//datacenter.jin10.com/reportType/dc_chinese_ppi_yoy",
    "中国以美元计算出口年率报告": "//datacenter.jin10.com/reportType/dc_chinese_exports_yoy",
    "中国以美元计算进口年率报告": "//datacenter.jin10.com/reportType/dc_chinese_imports_yoy",
    "中国以美元计算贸易帐报告": "//datacenter.jin10.com/reportType/dc_chinese_trade_balance",
    "中国规模以上工业增加值年率报告": "//datacenter.jin10.com/reportType/dc_chinese_industrial_production_yoy",
    "中国官方制造业PMI报告": "//datacenter.jin10.com/reportType/dc_chinese_manufacturing_pmi",
    "中国财新制造业PMI终值报告": "//datacenter.jin10.com/reportType/dc_chinese_caixin_manufacturing_pmi",
    "中国财新服务业PMI报告": "//datacenter.jin10.com/reportType/dc_chinese_caixin_services_pmi",
    "中国外汇储备报告": "//datacenter.jin10.com/reportType/dc_chinese_fx_reserves",
    "中国M2货币供应年率报告": "//datacenter.jin10.com/reportType/dc_chinese_m2_money_supply_yoy",
    "中国GDP年率报告": "//datacenter.jin10.com/reportType/dc_chinese_gdp_yoy",
    "人民币汇率中间价报告": "//datacenter.jin10.com/reportType/dc_rmb_data",
    "在岸人民币成交量报告": "//datacenter.jin10.com/reportType/dc_dollar_rmb_report",
    "上海期货交易所期货合约行情": "//datacenter.jin10.com/reportType/dc_shfe_futures_data",
    "中国CPI月率报告": "//datacenter.jin10.com/reportType/dc_chinese_cpi_mom",
    "大连商品交易所期货每日行情": "//datacenter.jin10.com/reportType/dc_dce_futures_data",
    "中国金融期货交易所期货每日行情": "//datacenter.jin10.com/reportType/dc_cffex_futures_data",
    "同业拆借报告": "//datacenter.jin10.com/reportType/dc_shibor",
    "香港同业拆借报告": "//datacenter.jin10.com/reportType/dc_hk_market_info",
    "深圳融资融券报告": "//datacenter.jin10.com/reportType/dc_market_margin_sz",
    "上海融资融券报告": "//datacenter.jin10.com/reportType/dc_market_margin_sse",
    "上海黄金交易所报告": "//datacenter.jin10.com/reportType/dc_sge_report",
    "上海期货交易所仓单日报": "//datacenter.jin10.com/reportType/dc_shfe_daily_stock",
    "大连商品交易所仓单日报": "//datacenter.jin10.com/reportType/dc_dce_daily_stock",
    "郑州商品交易所仓单日报": "//datacenter.jin10.com/reportType/dc_czce_daily_stock",
    "上海期货交易所指定交割仓库库存周报": "//datacenter.jin10.com/reportType/dc_shfe_weekly_stock",
    "CCI指数5500大卡动力煤价格报告": "//datacenter.jin10.com/reportType/dc_cci_report",
    "沿海六大电厂库存动态报告": "//datacenter.jin10.com/reportType/dc_qihuo_energy_report",
    "国内期货市场实施热度报告": "//datacenter.jin10.com/reportType/dc_futures_market_realtime",
    "中国官方非制造业PMI报告": "//datacenter.jin10.com/reportType/dc_chinese_non_manufacturing_pmi",
}
euro_name_url_map = {
    "欧元区未季调贸易帐报告": "//datacenter.jin10.com/reportType/dc_eurozone_trade_balance_mom",
    "欧元区季度GDP年率报告": "//datacenter.jin10.com/reportType/dc_eurozone_gdp_yoy",
    "欧元区CPI年率报告": "//datacenter.jin10.com/reportType/dc_eurozone_cpi_yoy",
    "欧元区PPI月率报告": "//datacenter.jin10.com/reportType/dc_eurozone_ppi_mom",
    "欧元区零售销售月率报告": "//datacenter.jin10.com/reportType/dc_eurozone_retail_sales_mom",
    "欧元区季调后就业人数季率报告": "//datacenter.jin10.com/reportType/dc_eurozone_employment_change_qoq",
    "欧元区失业率报告": "//datacenter.jin10.com/reportType/dc_eurozone_unemployment_rate_mom",
    "欧元区CPI月率报告": "//datacenter.jin10.com/reportType/dc_eurozone_cpi_mom",
    "欧元区经常帐报告": "//datacenter.jin10.com/reportType/dc_eurozone_current_account_mom",
    "欧元区工业产出月率报告": "//datacenter.jin10.com/reportType/dc_eurozone_industrial_production_mom",
    "欧元区制造业PMI初值报告": "//datacenter.jin10.com/reportType/dc_eurozone_manufacturing_pmi",
    "欧元区服务业PMI终值报告": "//datacenter.jin10.com/reportType/dc_eurozone_services_pmi",
    "欧元区ZEW经济景气指数报告": "//datacenter.jin10.com/reportType/dc_eurozone_zew_economic_sentiment",
    "欧元区Sentix投资者信心指数报告": "//datacenter.jin10.com/reportType/dc_eurozone_sentix_investor_confidence",
}
world_central_bank_map = {
    "美联储决议报告": "//datacenter.jin10.com/reportType/dc_usa_interest_rate_decision",
    "欧洲央行决议报告": "//datacenter.jin10.com/reportType/dc_interest_rate_decision",
    "新西兰联储决议报告": "//datacenter.jin10.com/reportType/dc_newzealand_interest_rate_decision",
    "中国央行决议报告": "//datacenter.jin10.com/reportType/dc_china_interest_rate_decision",
    "瑞士央行决议报告": "//datacenter.jin10.com/reportType/dc_switzerland_interest_rate_decision",
    "英国央行决议报告": "//datacenter.jin10.com/reportType/dc_english_interest_rate_decision",
    "澳洲联储决议报告": "//datacenter.jin10.com/reportType/dc_australia_interest_rate_decision",
    "日本央行决议报告": "//datacenter.jin10.com/reportType/dc_japan_interest_rate_decision",
    "印度央行决议报告": "//datacenter.jin10.com/reportType/dc_india_interest_rate_decision",
    "俄罗斯央行决议报告": "//datacenter.jin10.com/reportType/dc_russia_interest_rate_decision",
    "巴西央行决议报告": "//datacenter.jin10.com/reportType/dc_brazil_interest_rate_decision",
}
constitute_report_map = {
    "全球最大黄金ETF—SPDR Gold Trust持仓报告": "//datacenter.jin10.com/reportType/dc_etf_gold",
    "全球最大白银ETF--iShares Silver Trust持仓报告": "//datacenter.jin10.com/reportType/dc_etf_sliver",
    "芝加哥商业交易所（CME）能源类商品成交量报告": "//datacenter.jin10.com/reportType/dc_cme_energy_report",
    "美国商品期货交易委员会CFTC外汇类非商业持仓报告": "//datacenter.jin10.com/reportType/dc_cftc_nc_report",
    "美国商品期货交易委员会CFTC商品类非商业持仓报告": "//datacenter.jin10.com/reportType/dc_cftc_c_report",
    "芝加哥商业交易所（CME）金属类商品成交量报告": "//datacenter.jin10.com/reportType/dc_cme_report",
    "芝加哥商业交易所（CME）外汇类商品成交量报告": "//datacenter.jin10.com/reportType/dc_cme_fx_report",
    "伦敦金属交易所（LME）库存报告": "//datacenter.jin10.com/reportType/dc_lme_report",
    "伦敦金属交易所（LME）持仓报告": "//datacenter.jin10.com/reportType/dc_lme_traders_report",
    "美国商品期货交易委员会CFTC商品类商业持仓报告": "//datacenter.jin10.com/reportType/dc_cftc_merchant_goods",
    "美国商品期货交易委员会CFTC外汇类商业持仓报告": "//datacenter.jin10.com/reportType/dc_cftc_merchant_currency",
}
other_map = {
    "投机情绪报告": "//datacenter.jin10.com/reportType/dc_ssi_trends",
    "外汇实时波动监控": "//datacenter.jin10.com/reportType/dc_myFxBook_heat_map",
    "外汇相关性报告": "//datacenter.jin10.com/reportType/dc_myFxBook_correlation",
    "加密货币实时行情": "//datacenter.jin10.com/reportType/dc_bitcoin_current",
}
main_map = {
    "全球最大黄金ETF—SPDR Gold Trust持仓报告": "//datacenter.jin10.com/reportType/dc_etf_gold",
    "全球最大白银ETF--iShares Silver Trust持仓报告": "//datacenter.jin10.com/reportType/dc_etf_sliver",
    "美国非农就业人数报告": "//datacenter.jin10.com/reportType/dc_nonfarm_payrolls",
    "投机情绪报告": "//datacenter.jin10.com/reportType/dc_ssi_trends",
    "数据达人 — 复合报告": "//datacenter.jin10.com/reportType/dc_complex_report?complexType=1",
    "投行订单": "//datacenter.jin10.com/banks_orders",
    "行情报价": "//datacenter.jin10.com/price_wall",
    "美国EIA原油库存报告": "//datacenter.jin10.com/reportType/dc_eia_crude_oil",
    "欧佩克报告": "//datacenter.jin10.com/reportType/dc_opec_report",
}



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/3/5 17:30
Desc: 东方财富网-数据中心-期货库存数据
https://data.eastmoney.com/ifdata/kcsj.html
"""

import pandas as pd
import requests
from akshare.futures.cons import futures_inventory_em_symbol_dict


def futures_inventory_em(symbol: str = "a") -> pd.DataFrame:
    """
    东方财富网-数据中心-期货库存数据
    https://data.eastmoney.com/ifdata/kcsj.html
    :param symbol: 支持品种代码和中文名称，中文名称参见：https://data.eastmoney.com/ifdata/kcsj.html
    :type symbol: str
    :return: 指定品种的库存数据
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        "reportName": "RPT_FUTU_POSITIONCODE",
        "columns": "TRADE_MARKET_CODE,TRADE_CODE,TRADE_TYPE",
        "filter": '(IS_MAINCODE="1")',
        "pageNumber": "1",
        "pageSize": "500",
        "source": "WEB",
        "client": "WEB",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["result"]["data"])
    symbol_dict = dict(zip(temp_df["TRADE_TYPE"], temp_df["TRADE_CODE"]))
    if symbol in symbol_dict.keys():
        product_id = symbol_dict[symbol]
    elif symbol in futures_inventory_em_symbol_dict.keys():  # 如果输入的是代码
        product_id = futures_inventory_em_symbol_dict[symbol]
    else:
        raise ValueError(f"请输入正确的 symbol, 可选项为: {symbol_dict}")
    params = {
        "reportName": "RPT_FUTU_STOCKDATA",
        "columns": "SECURITY_CODE,TRADE_DATE,ON_WARRANT_NUM,ADDCHANGE",
        "filter": f"""(SECURITY_CODE="{product_id}")(TRADE_DATE>='2020-10-28')""",
        "pageNumber": "1",
        "pageSize": "500",
        "sortTypes": "-1",
        "sortColumns": "TRADE_DATE",
        "source": "WEB",
        "client": "WEB",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["result"]["data"])
    temp_df.columns = ["-", "日期", "库存", "增减"]
    temp_df = temp_df[["日期", "库存", "增减"]]
    temp_df.sort_values(["日期"], inplace=True)
    temp_df.reset_index(inplace=True, drop=True)
    temp_df["库存"] = pd.to_numeric(temp_df["库存"], errors="coerce")
    temp_df["增减"] = pd.to_numeric(temp_df["增减"], errors="coerce")
    temp_df["日期"] = pd.to_datetime(temp_df["日期"], errors="coerce").dt.date
    return temp_df


if __name__ == "__main__":
    futures_inventory_em_df = futures_inventory_em(symbol="a")
    print(futures_inventory_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/8/15 18:00
Desc: 同花顺-数据中心-资金流向
同花顺-数据中心-资金流向-个股资金流
https://data.10jqka.com.cn/funds/ggzjl/#refCountId=data_55f13c2c_254
同花顺-数据中心-资金流向-概念资金流
https://data.10jqka.com.cn/funds/gnzjl/#refCountId=data_55f13c2c_254
同花顺-数据中心-资金流向-行业资金流
https://data.10jqka.com.cn/funds/hyzjl/#refCountId=data_55f13c2c_254
同花顺-数据中心-资金流向-打单追踪
https://data.10jqka.com.cn/funds/ddzz/#refCountId=data_55f13c2c_254
"""

from io import StringIO

import pandas as pd
import requests
from bs4 import BeautifulSoup
import py_mini_racer
from akshare.utils.tqdm import get_tqdm

from akshare.datasets import get_ths_js


def _get_file_content_ths(file: str = "ths.js") -> str:
    """
    获取 JS 文件的内容
    :param file:  JS 文件名
    :type file: str
    :return: 文件内容
    :rtype: str
    """
    setting_file_path = get_ths_js(file)
    with open(setting_file_path, encoding="utf-8") as f:
        file_data = f.read()
    return file_data


def stock_fund_flow_individual(symbol: str = "即时") -> pd.DataFrame:
    """
    同花顺-数据中心-资金流向-个股资金流
    https://data.10jqka.com.cn/funds/ggzjl/#refCountId=data_55f13c2c_254
    :param symbol: choice of {“即时”, "3日排行", "5日排行", "10日排行", "20日排行"}
    :type symbol: str
    :return: 个股资金流
    :rtype: pandas.DataFrame
    """
    js_code = py_mini_racer.MiniRacer()
    js_content = _get_file_content_ths("ths.js")
    js_code.eval(js_content)
    v_code = js_code.call("v")
    headers = {
        "Accept": "text/html, */*; q=0.01",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
        "Cache-Control": "no-cache",
        "Connection": "keep-alive",
        "hexin-v": v_code,
        "Host": "data.10jqka.com.cn",
        "Pragma": "no-cache",
        "Referer": "http://data.10jqka.com.cn/funds/hyzjl/",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/90.0.4430.85 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    url = "http://data.10jqka.com.cn/funds/ggzjl/field/code/order/desc/ajax/1/free/1/"
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.text, features="lxml")
    raw_page = soup.find(name="span", attrs={"class": "page_info"}).text
    page_num = raw_page.split("/")[1]
    if symbol == "3日排行":
        url = "http://data.10jqka.com.cn/funds/ggzjl/board/3/field/zdf/order/desc/page/{}/ajax/1/free/1/"
    elif symbol == "5日排行":
        url = "http://data.10jqka.com.cn/funds/ggzjl/board/5/field/zdf/order/desc/page/{}/ajax/1/free/1/"
    elif symbol == "10日排行":
        url = "http://data.10jqka.com.cn/funds/ggzjl/board/10/field/zdf/order/desc/page/{}/ajax/1/free/1/"
    elif symbol == "20日排行":
        url = "http://data.10jqka.com.cn/funds/ggzjl/board/20/field/zdf/order/desc/page/{}/ajax/1/free/1/"
    else:
        url = "http://data.10jqka.com.cn/funds/ggzjl/field/zdf/order/desc/page/{}/ajax/1/free/1/"
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, int(page_num) + 1), leave=False):
        js_code = py_mini_racer.MiniRacer()
        js_content = _get_file_content_ths("ths.js")
        js_code.eval(js_content)
        v_code = js_code.call("v")
        headers = {
            "Accept": "text/html, */*; q=0.01",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
            "Cache-Control": "no-cache",
            "Connection": "keep-alive",
            "hexin-v": v_code,
            "Host": "data.10jqka.com.cn",
            "Pragma": "no-cache",
            "Referer": "http://data.10jqka.com.cn/funds/hyzjl/",
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
            "Chrome/90.0.4430.85 Safari/537.36",
            "X-Requested-With": "XMLHttpRequest",
        }
        r = requests.get(url.format(page), headers=headers)
        temp_df = pd.read_html(StringIO(r.text))[0]
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)

    del big_df["序号"]
    big_df.reset_index(inplace=True)
    big_df["index"] = range(1, len(big_df) + 1)
    if symbol == "即时":
        big_df.columns = [
            "序号",
            "股票代码",
            "股票简称",
            "最新价",
            "涨跌幅",
            "换手率",
            "流入资金",
            "流出资金",
            "净额",
            "成交额",
        ]
    else:
        big_df.columns = [
            "序号",
            "股票代码",
            "股票简称",
            "最新价",
            "阶段涨跌幅",
            "连续换手率",
            "资金流入净额",
        ]
    return big_df


def stock_fund_flow_concept(symbol: str = "即时") -> pd.DataFrame:
    """
    同花顺-数据中心-资金流向-概念资金流
    https://data.10jqka.com.cn/funds/gnzjl/#refCountId=data_55f13c2c_254
    :param symbol: choice of {“即时”, "3日排行", "5日排行", "10日排行", "20日排行"}
    :type symbol: str
    :return: 概念资金流
    :rtype: pandas.DataFrame
    """
    js_code = py_mini_racer.MiniRacer()
    js_content = _get_file_content_ths("ths.js")
    js_code.eval(js_content)
    v_code = js_code.call("v")
    headers = {
        "Accept": "text/html, */*; q=0.01",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
        "Cache-Control": "no-cache",
        "Connection": "keep-alive",
        "hexin-v": v_code,
        "Host": "data.10jqka.com.cn",
        "Pragma": "no-cache",
        "Referer": "http://data.10jqka.com.cn/funds/gnzjl/",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/90.0.4430.85 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    url = (
        "http://data.10jqka.com.cn/funds/gnzjl/field/tradezdf/order/desc/ajax/1/free/1/"
    )
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.text, features="lxml")
    raw_page = soup.find(name="span", attrs={"class": "page_info"}).text
    page_num = raw_page.split("/")[1]
    if symbol == "3日排行":
        url = "http://data.10jqka.com.cn/funds/gnzjl/board/3/field/tradezdf/order/desc/page/{}/ajax/1/free/1/"
    elif symbol == "5日排行":
        url = "http://data.10jqka.com.cn/funds/gnzjl/board/5/field/tradezdf/order/desc/page/{}/ajax/1/free/1/"
    elif symbol == "10日排行":
        url = "http://data.10jqka.com.cn/funds/gnzjl/board/10/field/tradezdf/order/desc/page/{}/ajax/1/free/1/"
    elif symbol == "20日排行":
        url = "http://data.10jqka.com.cn/funds/gnzjl/board/20/field/tradezdf/order/desc/page/{}/ajax/1/free/1/"
    else:
        url = "http://data.10jqka.com.cn/funds/gnzjl/field/tradezdf/order/desc/page/{}/ajax/1/free/1/"
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, int(page_num) + 1), leave=False):
        js_code = py_mini_racer.MiniRacer()
        js_content = _get_file_content_ths("ths.js")
        js_code.eval(js_content)
        v_code = js_code.call("v")
        headers = {
            "Accept": "text/html, */*; q=0.01",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
            "Cache-Control": "no-cache",
            "Connection": "keep-alive",
            "hexin-v": v_code,
            "Host": "data.10jqka.com.cn",
            "Pragma": "no-cache",
            "Referer": "http://data.10jqka.com.cn/funds/gnzjl/",
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
            "Chrome/90.0.4430.85 Safari/537.36",
            "X-Requested-With": "XMLHttpRequest",
        }
        r = requests.get(url.format(page), headers=headers)
        temp_df = pd.read_html(StringIO(r.text))[0]
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)

    del big_df["序号"]
    big_df.reset_index(inplace=True)
    big_df["index"] = range(1, len(big_df) + 1)
    if symbol == "即时":
        big_df.columns = [
            "序号",
            "行业",
            "行业指数",
            "行业-涨跌幅",
            "流入资金",
            "流出资金",
            "净额",
            "公司家数",
            "领涨股",
            "领涨股-涨跌幅",
            "当前价",
        ]
        big_df["行业-涨跌幅"] = big_df["行业-涨跌幅"].str.strip("%")
        big_df["领涨股-涨跌幅"] = big_df["领涨股-涨跌幅"].str.strip("%")
        big_df["行业-涨跌幅"] = pd.to_numeric(big_df["行业-涨跌幅"], errors="coerce")
        big_df["领涨股-涨跌幅"] = pd.to_numeric(
            big_df["领涨股-涨跌幅"], errors="coerce"
        )
    else:
        big_df.columns = [
            "序号",
            "行业",
            "公司家数",
            "行业指数",
            "阶段涨跌幅",
            "流入资金",
            "流出资金",
            "净额",
        ]
    return big_df


def stock_fund_flow_industry(symbol: str = "即时") -> pd.DataFrame:
    """
    同花顺-数据中心-资金流向-行业资金流
    https://data.10jqka.com.cn/funds/hyzjl/#refCountId=data_55f13c2c_254
    :param symbol: choice of {“即时”, "3日排行", "5日排行", "10日排行", "20日排行"}
    :type symbol: str
    :return: 行业资金流
    :rtype: pandas.DataFrame
    """
    js_code = py_mini_racer.MiniRacer()
    js_content = _get_file_content_ths("ths.js")
    js_code.eval(js_content)
    v_code = js_code.call("v")
    headers = {
        "Accept": "text/html, */*; q=0.01",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
        "Cache-Control": "no-cache",
        "Connection": "keep-alive",
        "hexin-v": v_code,
        "Host": "data.10jqka.com.cn",
        "Pragma": "no-cache",
        "Referer": "http://data.10jqka.com.cn/funds/hyzjl/",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/90.0.4430.85 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    url = (
        "http://data.10jqka.com.cn/funds/hyzjl/field/tradezdf/order/desc/ajax/1/free/1/"
    )
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.text, features="lxml")
    raw_page = soup.find(name="span", attrs={"class": "page_info"}).text
    page_num = raw_page.split("/")[1]
    if symbol == "3日排行":
        url = "http://data.10jqka.com.cn/funds/hyzjl/board/3/field/tradezdf/order/desc/page/{}/ajax/1/free/1/"
    elif symbol == "5日排行":
        url = "http://data.10jqka.com.cn/funds/hyzjl/board/5/field/tradezdf/order/desc/page/{}/ajax/1/free/1/"
    elif symbol == "10日排行":
        url = "http://data.10jqka.com.cn/funds/hyzjl/board/10/field/tradezdf/order/desc/page/{}/ajax/1/free/1/"
    elif symbol == "20日排行":
        url = "http://data.10jqka.com.cn/funds/hyzjl/board/20/field/tradezdf/order/desc/page/{}/ajax/1/free/1/"
    else:
        url = "http://data.10jqka.com.cn/funds/hyzjl/field/tradezdf/order/desc/page/{}/ajax/1/free/1/"
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, int(page_num) + 1), leave=False):
        js_code = py_mini_racer.MiniRacer()
        js_content = _get_file_content_ths("ths.js")
        js_code.eval(js_content)
        v_code = js_code.call("v")
        headers = {
            "Accept": "text/html, */*; q=0.01",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
            "Cache-Control": "no-cache",
            "Connection": "keep-alive",
            "hexin-v": v_code,
            "Host": "data.10jqka.com.cn",
            "Pragma": "no-cache",
            "Referer": "http://data.10jqka.com.cn/funds/hyzjl/",
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
            "Chrome/90.0.4430.85 Safari/537.36",
            "X-Requested-With": "XMLHttpRequest",
        }
        r = requests.get(url.format(page), headers=headers)
        temp_df = pd.read_html(StringIO(r.text))[0]
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)

    del big_df["序号"]
    big_df.reset_index(inplace=True)
    big_df["index"] = range(1, len(big_df) + 1)
    if symbol == "即时":
        big_df.columns = [
            "序号",
            "行业",
            "行业指数",
            "行业-涨跌幅",
            "流入资金",
            "流出资金",
            "净额",
            "公司家数",
            "领涨股",
            "领涨股-涨跌幅",
            "当前价",
        ]
        big_df["行业-涨跌幅"] = big_df["行业-涨跌幅"].str.strip("%")
        big_df["领涨股-涨跌幅"] = big_df["领涨股-涨跌幅"].str.strip("%")
        big_df["行业-涨跌幅"] = pd.to_numeric(big_df["行业-涨跌幅"], errors="coerce")
        big_df["领涨股-涨跌幅"] = pd.to_numeric(
            big_df["领涨股-涨跌幅"], errors="coerce"
        )
    else:
        big_df.columns = [
            "序号",
            "行业",
            "公司家数",
            "行业指数",
            "阶段涨跌幅",
            "流入资金",
            "流出资金",
            "净额",
        ]
    return big_df


def stock_fund_flow_big_deal() -> pd.DataFrame:
    """
    同花顺-数据中心-资金流向-大单追踪
    https://data.10jqka.com.cn/funds/ddzz
    :return: 大单追踪
    :rtype: pandas.DataFrame
    """
    js_code = py_mini_racer.MiniRacer()
    js_content = _get_file_content_ths("ths.js")
    js_code.eval(js_content)
    v_code = js_code.call("v")
    headers = {
        "Accept": "text/html, */*; q=0.01",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
        "Cache-Control": "no-cache",
        "Connection": "keep-alive",
        "hexin-v": v_code,
        "Host": "data.10jqka.com.cn",
        "Pragma": "no-cache",
        "Referer": "http://data.10jqka.com.cn/funds/hyzjl/",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/90.0.4430.85 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    url = "http://data.10jqka.com.cn/funds/ddzz/order/desc/ajax/1/free/1/"
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.text, features="lxml")
    raw_page = soup.find(name="span", attrs={"class": "page_info"}).text
    page_num = raw_page.split("/")[1]
    url = "http://data.10jqka.com.cn/funds/ddzz/order/asc/page/{}/ajax/1/free/1/"
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, int(page_num) + 1), leave=False):
        js_code = py_mini_racer.MiniRacer()
        js_content = _get_file_content_ths("ths.js")
        js_code.eval(js_content)
        v_code = js_code.call("v")
        headers = {
            "Accept": "text/html, */*; q=0.01",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
            "Cache-Control": "no-cache",
            "Connection": "keep-alive",
            "hexin-v": v_code,
            "Host": "data.10jqka.com.cn",
            "Pragma": "no-cache",
            "Referer": "http://data.10jqka.com.cn/funds/hyzjl/",
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
            "Chrome/90.0.4430.85 Safari/537.36",
            "X-Requested-With": "XMLHttpRequest",
        }
        r = requests.get(url.format(page), headers=headers)
        temp_df = pd.read_html(StringIO(r.text))[0]
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)

    big_df.columns = [
        "成交时间",
        "股票代码",
        "股票简称",
        "成交价格",
        "成交量",
        "成交额",
        "大单性质",
        "涨跌幅",
        "涨跌额",
        "详细",
    ]
    del big_df["详细"]
    return big_df


if __name__ == "__main__":
    # 同花顺-数据中心-资金流向-个股资金流
    stock_fund_flow_individual_df = stock_fund_flow_individual(symbol="即时")
    print(stock_fund_flow_individual_df)

    stock_fund_flow_individual_df = stock_fund_flow_individual(symbol="3日排行")
    print(stock_fund_flow_individual_df)

    stock_fund_flow_individual_df = stock_fund_flow_individual(symbol="5日排行")
    print(stock_fund_flow_individual_df)

    stock_fund_flow_individual_df = stock_fund_flow_individual(symbol="10日排行")
    print(stock_fund_flow_individual_df)

    stock_fund_flow_individual_df = stock_fund_flow_individual(symbol="20日排行")
    print(stock_fund_flow_individual_df)

    # 同花顺-数据中心-资金流向-概念资金流
    stock_fund_flow_concept_df = stock_fund_flow_concept(symbol="即时")
    print(stock_fund_flow_concept_df)

    stock_fund_flow_concept_df = stock_fund_flow_concept(symbol="3日排行")
    print(stock_fund_flow_concept_df)

    stock_fund_flow_concept_df = stock_fund_flow_concept(symbol="5日排行")
    print(stock_fund_flow_concept_df)

    stock_fund_flow_concept_df = stock_fund_flow_concept(symbol="10日排行")
    print(stock_fund_flow_concept_df)

    stock_fund_flow_concept_df = stock_fund_flow_concept(symbol="20日排行")
    print(stock_fund_flow_concept_df)

    # 同花顺-数据中心-资金流向-行业资金流
    stock_fund_flow_industry_df = stock_fund_flow_industry(symbol="即时")
    print(stock_fund_flow_industry_df)

    stock_fund_flow_industry_df = stock_fund_flow_industry(symbol="3日排行")
    print(stock_fund_flow_industry_df)

    stock_fund_flow_industry_df = stock_fund_flow_industry(symbol="5日排行")
    print(stock_fund_flow_industry_df)

    stock_fund_flow_industry_df = stock_fund_flow_industry(symbol="10日排行")
    print(stock_fund_flow_industry_df)

    stock_fund_flow_industry_df = stock_fund_flow_industry(symbol="20日排行")
    print(stock_fund_flow_industry_df)

    # 同花顺-数据中心-资金流向-大单追踪
    stock_fund_flow_big_deal_df = stock_fund_flow_big_deal()
    print(stock_fund_flow_big_deal_df)



# -*- coding:utf-8 -*-
# !/usr/bin/env python
"""
Date: 2022/9/20 17:46
Desc: 中国债券信息网-中债指数-中债指数族系-总指数-综合类指数
"""

import pandas as pd
import requests


def bond_new_composite_index_cbond(
    indicator: str = "财富", period: str = "总值"
) -> pd.DataFrame:
    """
    中国债券信息网-中债指数-中债指数族系-总指数-综合类指数-中债-新综合指数
    https://yield.chinabond.com.cn/cbweb-mn/indices/single_index_query
    :param indicator: choice of {"全价", "净价", "财富", "平均市值法久期", "平均现金流法久期", "平均市值法凸性", "平均现金流法凸性", "平均现金流法到期收益率", "平均市值法到期收益率", "平均基点价值", "平均待偿期", "平均派息率", "指数上日总市值", "财富指数涨跌幅", "全价指数涨跌幅", "净价指数涨跌幅", "现券结算量"}
    :type indicator: str
    :param period: choice of {"总值", "1年以下", "1-3年", "3-5年", "5-7年", "7-10年", "10年以上", "0-3个月", "3-6个月", "6-9个月", "9-12个月", "0-6个月", "6-12个月"}
    :type period: str
    :return: 新综合指数
    :rtype: pandas.DataFrame
    """
    indicator_map = {
        "全价": "QJZS",
        "净价": "JJZS",
        "财富": "CFZS",
        "平均市值法久期": "PJSZFJQ",
        "平均现金流法久期": "PJXJLFJQ",
        "平均市值法凸性": "PJSZFTX",
        "平均现金流法凸性": "PJXJLFTX",
        "平均现金流法到期收益率": "PJDQSYL",
        "平均市值法到期收益率": "PJSZFDQSYL",
        "平均基点价值": "PJJDJZ",
        "平均待偿期": "PJDCQ",
        "平均派息率": "PJPXL",
        "指数上日总市值": "ZSZSZ",
        "财富指数涨跌幅": "CFZSZDF",
        "全价指数涨跌幅": "QJZSZDF",
        "净价指数涨跌幅": "JJZSZDF",
        "现券结算量": "XQJSL",
    }
    period_map = {
        "总值": "00",
        "1年以下": "01",
        "1-3年": "02",
        "3-5年": "03",
        "5-7年": "04",
        "7-10年": "05",
        "10年以上": "06",
        "0-3个月": "07",
        "3-6个月": "08",
        "6-9个月": "09",
        "9-12个月": "10",
        "0-6个月": "11",
        "6-12个月": "12",
    }
    url = "https://yield.chinabond.com.cn/cbweb-mn/indices/singleIndexQuery"
    params = {
        "indexid": "8a8b2ca0332abed20134ea76d8885831",
        "": "",  # noqa: F601
        "qxlxt": period_map[period],
        "": "",  # noqa: F601
        "ltcslx": "",
        "": "",  # noqa: F601
        "zslxt": indicator_map[indicator],  # noqa: F601
        "": "",  # noqa: F601
        "zslxt": indicator_map[indicator],  # noqa: F601
        "": "",  # noqa: F601
        "lx": "1",
        "": "",  # noqa: F601
        "locale": "",
    }
    r = requests.post(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame.from_dict(
        data_json[f"{indicator_map[indicator]}_{period_map[period]}"],
        orient="index",
    )
    temp_df.reset_index(inplace=True)
    temp_df.columns = ["date", "value"]
    temp_df["date"] = temp_df["date"].astype(float)
    temp_df["date"] = (
        pd.to_datetime(temp_df["date"], unit="ms", errors="coerce", utc=True)
        .dt.tz_convert("Asia/Shanghai")
        .dt.date
    )
    temp_df["value"] = pd.to_numeric(temp_df["value"], errors="coerce")
    return temp_df


def bond_composite_index_cbond(
    indicator: str = "财富", period: str = "总值"
) -> pd.DataFrame:
    """
    中国债券信息网-中债指数-中债指数族系-总指数-综合类指数-中债-综合指数
    https://yield.chinabond.com.cn/cbweb-mn/indices/single_index_query
    :param indicator: choice of {"全价", "净价", "财富", "平均市值法久期", "平均现金流法久期", "平均市值法凸性", "平均现金流法凸性", "平均现金流法到期收益率", "平均市值法到期收益率", "平均基点价值", "平均待偿期", "平均派息率", "指数上日总市值", "财富指数涨跌幅", "全价指数涨跌幅", "净价指数涨跌幅", "现券结算量"}
    :type indicator: str
    :param period: choice of {"总值", "1年以下", "1-3年", "3-5年", "5-7年", "7-10年", "10年以上", "0-3个月", "3-6个月", "6-9个月", "9-12个月", "0-6个月", "6-12个月"}
    :type period: str
    :return: 新综合指数
    :rtype: pandas.DataFrame
    """
    indicator_map = {
        "全价": "QJZS",
        "净价": "JJZS",
        "财富": "CFZS",
        "平均市值法久期": "PJSZFJQ",
        "平均现金流法久期": "PJXJLFJQ",
        "平均市值法凸性": "PJSZFTX",
        "平均现金流法凸性": "PJXJLFTX",
        "平均现金流法到期收益率": "PJDQSYL",
        "平均市值法到期收益率": "PJSZFDQSYL",
        "平均基点价值": "PJJDJZ",
        "平均待偿期": "PJDCQ",
        "平均派息率": "PJPXL",
        "指数上日总市值": "ZSZSZ",
        "财富指数涨跌幅": "CFZSZDF",
        "全价指数涨跌幅": "QJZSZDF",
        "净价指数涨跌幅": "JJZSZDF",
        "现券结算量": "XQJSL",
    }
    period_map = {
        "总值": "00",
        "1年以下": "01",
        "1-3年": "02",
        "3-5年": "03",
        "5-7年": "04",
        "7-10年": "05",
        "10年以上": "06",
        "0-3个月": "07",
        "3-6个月": "08",
        "6-9个月": "09",
        "9-12个月": "10",
        "0-6个月": "11",
        "6-12个月": "12",
    }
    url = "https://yield.chinabond.com.cn/cbweb-mn/indices/singleIndexQuery"
    params = {
        "indexid": "2c90818811afed8d0111c0c672b31578",
        "": "",  # noqa: F601
        "qxlxt": period_map[period],
        "": "",  # noqa: F601
        "zslxt": indicator_map[indicator],
        "": "",  # noqa: F601
        "lx": "1",
        "": "",  # noqa: F601
        "locale": "",
    }
    r = requests.post(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame.from_dict(
        data_json[f"{indicator_map[indicator]}_{period_map[period]}"],
        orient="index",
    )
    temp_df.reset_index(inplace=True)
    temp_df.columns = ["date", "value"]
    temp_df["date"] = pd.to_datetime(temp_df["date"], unit="ms").dt.date
    temp_df["value"] = pd.to_numeric(temp_df["value"])
    return temp_df


if __name__ == "__main__":
    bond_new_composite_index_cbond_df = bond_new_composite_index_cbond(
        indicator="财富", period="总值"
    )
    print(bond_new_composite_index_cbond_df)

    bond_composite_index_cbond_df = bond_composite_index_cbond(
        indicator="财富", period="总值"
    )
    print(bond_composite_index_cbond_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/2/21 18:00
Desc: 新浪财经-日内分时数据
https://quote.eastmoney.com/f1.html?newcode=0.000001
"""

import math

import pandas as pd
import requests

from akshare.utils.tqdm import get_tqdm


def stock_intraday_sina(
    symbol: str = "sz000001", date: str = "20240321"
) -> pd.DataFrame:
    """
    新浪财经-日内分时数据
    https://vip.stock.finance.sina.com.cn/quotes_service/view/cn_bill.php?symbol=sz000001
    :param symbol: 股票代码
    :type symbol: str
    :param date: 交易日
    :type date: str
    :return: 分时数据
    :rtype: pandas.DataFrame
    """
    url = "https://vip.stock.finance.sina.com.cn/quotes_service/api/json_v2.php/CN_Bill.GetBillListCount"
    params = {
        "symbol": f"{symbol}",
        "num": "60",
        "page": "1",
        "sort": "ticktime",
        "asc": "0",
        "volume": "0",
        "amount": "0",
        "type": "0",
        "day": "-".join([date[:4], date[4:6], date[6:]]),
    }
    headers = {
        "Referer": f"https://vip.stock.finance.sina.com.cn/quotes_service/view/cn_bill.php?symbol={symbol}",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/107.0.0.0 Safari/537.36",
    }
    r = requests.get(url=url, params=params, headers=headers)
    data_json = r.json()
    total_page = math.ceil(int(data_json) / 60)
    url = "https://vip.stock.finance.sina.com.cn/quotes_service/api/json_v2.php/CN_Bill.GetBillList"
    big_df = pd.DataFrame()
    tqdm = get_tqdm()
    for page in tqdm(range(1, total_page + 1), leave=False):
        params.update({"page": page})
        r = requests.get(url=url, params=params, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json)
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
    big_df.sort_values(by=["ticktime"], inplace=True, ignore_index=True)
    big_df["price"] = pd.to_numeric(big_df["price"], errors="coerce")
    big_df["volume"] = pd.to_numeric(big_df["volume"], errors="coerce")
    big_df["prev_price"] = pd.to_numeric(big_df["prev_price"], errors="coerce")
    return big_df


if __name__ == "__main__":
    stock_intraday_sina_df = stock_intraday_sina(symbol="sz000001", date="20250221")
    print(stock_intraday_sina_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/4/3 16:08
Desc: 金十数据-数据中心-主要机构-宏观经济
https://datacenter.jin10.com/
"""

import datetime
import time

import pandas as pd
import requests
from tqdm import tqdm


def macro_cons_gold() -> pd.DataFrame:
    """
    全球最大黄金 ETF—SPDR Gold Trust 持仓报告, 数据区间从 20041118-至今
    https://datacenter.jin10.com/reportType/dc_etf_gold
    :return: 持仓报告
    :rtype: pandas.DataFrame
    """
    t = time.time()
    headers = {
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/107.0.0.0 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "x-csrf-token",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "category": "etf",
        "attr_id": "1",
        "max_date": "",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df.columns = [
        "日期",
        "总库存",
        "增持/减持",
        "总价值",
    ]
    big_df["商品"] = "黄金"
    big_df = big_df[
        [
            "商品",
            "日期",
            "总库存",
            "增持/减持",
            "总价值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"], errors="coerce").dt.date
    big_df["总库存"] = pd.to_numeric(big_df["总库存"], errors="coerce")
    big_df["增持/减持"] = pd.to_numeric(big_df["增持/减持"], errors="coerce")
    big_df["总价值"] = pd.to_numeric(big_df["总价值"], errors="coerce")
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


def macro_cons_silver() -> pd.DataFrame:
    """
    全球最大白银 ETF—SPDR Gold Trust 持仓报告, 数据区间从 20041118-至今
    https://datacenter.jin10.com/reportType/dc_etf_sliver
    :return: 持仓报告
    :rtype: pandas.DataFrame
    """
    t = time.time()
    headers = {
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/107.0.0.0 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "x-csrf-token",
        "x-version": "1.0.0",
    }
    url = "https://datacenter-api.jin10.com/reports/list_v2"
    params = {
        "category": "etf",
        "attr_id": "2",
        "max_date": "",
        "_": str(int(round(t * 1000))),
    }
    big_df = pd.DataFrame()
    while True:
        r = requests.get(url, params=params, headers=headers)
        data_json = r.json()
        if not data_json["data"]["values"]:
            break
        temp_df = pd.DataFrame(data_json["data"]["values"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)
        last_date_str = temp_df.iat[-1, 0]
        last_date_str = (
            (
                datetime.datetime.strptime(last_date_str, "%Y-%m-%d")
                - datetime.timedelta(days=1)
            )
            .date()
            .isoformat()
        )
        params.update({"max_date": f"{last_date_str}"})
    big_df.columns = [
        "日期",
        "总库存",
        "增持/减持",
        "总价值",
    ]
    big_df["商品"] = "白银"
    big_df = big_df[
        [
            "商品",
            "日期",
            "总库存",
            "增持/减持",
            "总价值",
        ]
    ]
    big_df["日期"] = pd.to_datetime(big_df["日期"], errors="coerce").dt.date
    big_df["总库存"] = pd.to_numeric(big_df["总库存"], errors="coerce")
    big_df["增持/减持"] = pd.to_numeric(big_df["增持/减持"], errors="coerce")
    big_df["总价值"] = pd.to_numeric(big_df["总价值"], errors="coerce")
    big_df.sort_values(["日期"], inplace=True)
    big_df.reset_index(inplace=True, drop=True)
    return big_df


def macro_cons_opec_month() -> pd.DataFrame:
    """
    欧佩克报告-月度, 数据区间从 20170118-至今
    这里返回的具体索引日期的数据为上一个月的数据, 由于某些国家的数据有缺失
    只选择有数据的国家返回
    20200312:fix:由于 “厄瓜多尔” 已经有几个月没有更新数据，在这里加以剔除
    https://datacenter.jin10.com/reportType/dc_opec_report
    :return: 欧佩克报告-月度
    :rtype: pandas.DataFrame
    """
    t = time.time()
    big_df = pd.DataFrame()
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "referer": "https://datacenter.jin10.com/reportType/dc_opec_report",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/79.0.3945.117 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-csrf-token": "",
        "x-version": "1.0.0",
    }
    res = requests.get(
        url=f"https://datacenter-api.jin10.com/reports/dates?category=opec&_={str(int(round(t * 1000)))}",
        headers=headers,
    )  # 日期序列
    all_date_list = res.json()["data"]
    bar = tqdm(reversed(all_date_list))
    for item in bar:
        bar.set_description(f"Please wait for a moment, now downloading {item}'s data")
        res = requests.get(
            url=f"https://datacenter-api.jin10.com/reports/list?"
            f"category=opec&date={item}&_={str(int(round(t * 1000)))}",
            headers=headers,
        )
        temp_df = pd.DataFrame(
            res.json()["data"]["values"],
            columns=pd.DataFrame(res.json()["data"]["keys"])["name"].tolist(),
        ).T
        temp_df.columns = temp_df.iloc[0, :]
        temp_df = temp_df.iloc[1:, :]
        try:
            temp_df = temp_df[
                [
                    "阿尔及利亚",
                    "安哥拉",
                    "加蓬",
                    "伊朗",
                    "伊拉克",
                    "科威特",
                    "利比亚",
                    "尼日利亚",
                    "沙特",
                    "阿联酋",
                    "委内瑞拉",
                    "欧佩克产量",
                ]
            ].iloc[-2, :]
        except:  # noqa: E722
            temp_df = temp_df[
                [
                    "阿尔及利亚",
                    "安哥拉",
                    "加蓬",
                    "伊朗",
                    "伊拉克",
                    "科威特",
                    "利比亚",
                    "尼日利亚",
                    "沙特",
                    "阿联酋",
                    "委内瑞拉",
                    "欧佩克产量",
                ]
            ].iloc[-1, :]
        temp_df.dropna(inplace=True)
        big_df[temp_df.name] = temp_df
    big_df = big_df.T
    big_df = big_df.astype(float)
    big_df.reset_index(inplace=True)
    big_df.rename(columns={"index": "日期"}, inplace=True)
    big_df.columns.name = None
    return big_df


if __name__ == "__main__":
    macro_cons_gold_df = macro_cons_gold()
    print(macro_cons_gold_df)

    macro_cons_silver_df = macro_cons_silver()
    print(macro_cons_silver_df)

    macro_cons_opec_month_df = macro_cons_opec_month()
    print(macro_cons_opec_month_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/7/24 23:30
Desc: 巨潮资讯-数据中心-专题统计-公司治理-股权质押
https://webapi.cninfo.com.cn/#/thematicStatistics
"""

import pandas as pd
import py_mini_racer
import requests

from akshare.datasets import get_ths_js


def _get_file_content_ths(file: str = "cninfo.js") -> str:
    """
    获取 JS 文件的内容
    :param file:  JS 文件名
    :type file: str
    :return: 文件内容
    :rtype: str
    """
    setting_file_path = get_ths_js(file)
    with open(setting_file_path, encoding="utf-8") as f:
        file_data = f.read()
    return file_data


def stock_cg_equity_mortgage_cninfo(date: str = "20210930") -> pd.DataFrame:
    """
    巨潮资讯-数据中心-专题统计-公司治理-股权质押
    https://webapi.cninfo.com.cn/#/thematicStatistics
    :param date: 开始统计时间
    :type date: str
    :return: 股权质押
    :rtype: pandas.DataFrame
    """
    url = "https://webapi.cninfo.com.cn/api/sysapi/p_sysapi1094"
    js_code = py_mini_racer.MiniRacer()
    js_content = _get_file_content_ths("cninfo.js")
    js_code.eval(js_content)
    mcode = js_code.call("getResCode1")
    headers = {
        "Accept": "*/*",
        "Accept-Enckey": mcode,
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
        "Cache-Control": "no-cache",
        "Content-Length": "0",
        "Host": "webapi.cninfo.com.cn",
        "Origin": "https://webapi.cninfo.com.cn",
        "Pragma": "no-cache",
        "Proxy-Connection": "keep-alive",
        "Referer": "https://webapi.cninfo.com.cn/",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
        "Chrome/93.0.4577.63 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    params = {
        "tdate": "-".join([date[:4], date[4:6], date[6:]]),
    }
    r = requests.post(url, headers=headers, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["records"])
    temp_df.columns = [
        "质押解除数量",
        "股票简称",
        "公告日期",
        "质押事项",
        "质权人",
        "出质人",
        "股票代码",
        "占总股本比例",
        "累计质押占总股本比例",
        "质押数量",
    ]
    temp_df = temp_df[
        [
            "股票代码",
            "股票简称",
            "公告日期",
            "出质人",
            "质权人",
            "质押数量",
            "占总股本比例",
            "质押解除数量",
            "质押事项",
            "累计质押占总股本比例",
        ]
    ]
    temp_df["公告日期"] = pd.to_datetime(temp_df["公告日期"], errors="coerce").dt.date
    temp_df["质押数量"] = pd.to_numeric(temp_df["质押数量"], errors="coerce")
    temp_df["占总股本比例"] = pd.to_numeric(temp_df["占总股本比例"], errors="coerce")
    temp_df["质押解除数量"] = pd.to_numeric(temp_df["质押解除数量"], errors="coerce")
    temp_df["累计质押占总股本比例"] = pd.to_numeric(
        temp_df["累计质押占总股本比例"], errors="coerce"
    )
    return temp_df


if __name__ == "__main__":
    stock_cg_equity_mortgage_cninfo_df = stock_cg_equity_mortgage_cninfo(
        date="20210930"
    )
    print(stock_cg_equity_mortgage_cninfo_df)



class AkshareConfig:
    _instance = None

    def __new__(cls):
        if cls._instance is None:
            cls._instance = super().__new__(cls)
            cls._instance.proxies = None
        return cls._instance

    @classmethod
    def set_proxies(cls, proxies):
        cls().proxies = proxies

    @classmethod
    def get_proxies(cls):
        return cls().proxies


config = AkshareConfig()


# 导出 set_proxies 函数
def set_proxies(proxies):
    config.set_proxies(proxies)


def get_proxies():
    return config.get_proxies()


class ProxyContext:
    def __init__(self, proxies):
        self.proxies = proxies
        self.old_proxies = None

    def __enter__(self):
        self.old_proxies = config.get_proxies()
        config.set_proxies(self.proxies)
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        config.set_proxies(self.old_proxies)
        return False  # 不处理异常
